# presentation-card

Streamlit component that allows you to do X

## Installation instructions 

```sh
pip install presentation-card
```

## Usage instructions

```python
import streamlit as st

from presentation_card import presentation_card

value = presentation_card()

st.write(value)
